@@ -16,3 +16,10 @@ format_types = function(types) {
   paste0(types, collapse = ", ")
 }
 
+toproper <- function(str, split = " ", fixed = TRUE){
+  str = strsplit(str, split, fixed)
+  str = lapply(str, function(x){
+    paste0(toupper(substr(x,1,1)), tolower(substr(x,2,1000)), collapse = split)
+  })
+  return(unlist(str))
+}
