@@ -6,7 +6,7 @@
 #' @import mlr3pipelines
 #' @importFrom R6 R6Class
 #' @importFrom utils data head tail
-#' @importFrom stats reformulate model.matrix model.frame
+#' @importFrom stats reformulate model.matrix model.frame sd
 #' @importFrom survival Surv
 "_PACKAGE"
 
@@ -22,7 +22,7 @@ register_mlr3 = function() {
       # "density", "mlr3proba", "TaskDensity", "LearnerDensity", "PredictionDensity", "MeasureDensity",
       # "probreg", "mlr3proba", "TaskProbreg", "LearnerProbreg", "PredictionProbreg", "MeasureDensity"
     )), "type")
-    x$task_col_roles$surv = c("feature", "target", "label", "order", "group", "weight")
+    x$task_col_roles$surv = c("feature", "target", "label", "order", "group", "weight", "stratum")
     # x$task_col_roles$density = c("feature", "target", "label", "order", "group", "weight")
     # x$task_col_roles$probreg = c("feature", "target", "label", "order", "group", "weight")
     x$task_properties$surv = c("weights", "groups")
@@ -34,9 +34,10 @@ register_mlr3 = function() {
     x$measure_properties$surv = x$measure_properties$regr
     # x$measure_properties$density = x$measure_properties$regr
     # x$measure_properties$probreg = x$measure_properties$regr
-    x$learner_predict_types$surv = list(crank = c("crank","lp","distr"),
-                                        distr = c("crank","lp","distr"),
-                                        lp = c("crank","lp","distr"))
+    x$learner_predict_types$surv = list(crank = c("crank","lp","distr","response"),
+                                        distr = c("crank","lp","distr","response"),
+                                        lp = c("crank","lp","distr","response"),
+                                        response = c("crank","lp","distr","response"))
     x$default_measures$surv = "surv.harrellC"
   }
 
@@ -74,6 +75,7 @@ register_mlr3 = function() {
    x$add("surv.parametric", LearnerSurvParametric)
    x$add("surv.flexible", LearnerSurvFlexible)
    x$add("surv.gbm", LearnerSurvGBM)
+   x$add("surv.obliqueRSF", LearnerSurvObliqueRSF)
 
   # measures
    x = utils::getFromNamespace("mlr_measures", ns = "mlr3")
@@ -105,6 +107,13 @@ register_mlr3 = function() {
 
    x$add("surv.unoTNR", MeasureSurvUnoTNR)
    x$add("surv.songTNR", MeasureSurvSongTNR)
+
+   x$add("surv.rmse", MeasureSurvRMSE)
+   x$add("surv.rmseSE", MeasureSurvRMSESE)
+   x$add("surv.mse", MeasureSurvMSE)
+   x$add("surv.mseSE", MeasureSurvMSESE)
+   x$add("surv.mae", MeasureSurvMAE)
+   x$add("surv.maeSE", MeasureSurvMAESE)
 }
 register_mlr3pipelines = function(){
    x = utils::getFromNamespace("mlr_pipeops", ns = "mlr3pipelines")
