@@ -33,8 +33,9 @@ test_that("integrated_prob_losses", {
   probs = paste0("surv.", c("graf","grafSE","intlogloss","intloglossSE"))
   expect_error(lapply(probs, msr, times = 34:37, integrated = FALSE), "non-integrated score")
   expect_silent(prediction$score(lapply(probs, msr, integrated = TRUE)))
-  expect_silent(prediction$score(lapply(probs, msr, integrated = TRUE, times = c(34:70))))
-  expect_silent(prediction$score(lapply(probs, msr, integrated = FALSE, times = times)))
+  expect_error(prediction$score(lapply(probs, msr, integrated = TRUE, times = c(34:70))), "Times are all")
+  expect_silent(prediction$score(lapply(probs, msr, integrated = TRUE, times = c(2:3))))
+  expect_silent(prediction$score(lapply(probs, msr, integrated = FALSE, times = 2)))
 })
 
 # test_that("AUCs",{
